@@ -20,13 +20,13 @@ RSpec.describe "NIO acceptables" do
     let(:port) { next_available_tcp_port }
 
     let :acceptable_subject do
-      server = TCPServer.new("localhost", port)
-      TCPSocket.open("localhost", port)
+      server = TCPServer.new("127.0.0.1", port)
+      TCPSocket.open("127.0.0.1", port)
       server
     end
 
     let :unacceptable_subject do
-      TCPServer.new("localhost", port + 1)
+      TCPServer.new("127.0.0.1", port + 1)
     end
 
     it_behaves_like "an NIO acceptable"
